==> mysql-connector-java-6.0.3-sources.jar: com/mysql/cj/api/mysqla/result/ColumnDefinition.java <==
/*
  Copyright (c) 2016, Oracle and/or its affiliates. All rights reserved.

  The MySQL Connector/J is licensed under the terms of the GPLv2
  <http://www.gnu.org/licenses/old-licenses/gpl-2.0.html>, like most MySQL Connectors.
  There are special exceptions to the terms and conditions of the GPLv2 as it is applied to
  this software, see the FOSS License Exception
  <http://www.mysql.com/about/legal/licensing/foss-exception.html>.

  This program is free software; you can redistribute it and/or modify it under the terms
  of the GNU General Public License as published by the Free Software Foundation; version 2
  of the License.

  This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
  without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  See the GNU General Public License for more details.

  You should have received a copy of the GNU General Public License along with this
  program; if not, write to the Free Software Foundation, Inc., 51 Franklin St, Fifth
  Floor, Boston, MA 02110-1301  USA

 */

package com.mysql.cj.api.mysqla.result;

import java.util.Map;

import com.mysql.cj.core.result.Field;

/**
 * Represents Protocol::ColumnDefinition41 structure
 *
 */
public interface ColumnDefinition {

    Field[] getFields();

    void setFields(Field[] fields);

    /**
     * Builds a hash between column names and their indices for fast retrieval.
     * This is done lazily to support findColumn() and get*(String), as it
     * can be more expensive than just retrieving result set values by ordinal
     * index.
     */
    void buildIndexMapping();

    boolean hasBuiltIndexMapping();

    public Map<String, Integer> getColumnLabelToIndex();

    void setColumnLabelToIndex(Map<String, Integer> columnLabelToIndex);

    public Map<String, Integer> getFullColumnNameToIndex();

    void setFullColumnNameToIndex(Map<String, Integer> fullColNameToIndex);

    public Map<String, Integer> getColumnNameToIndex();

    void setColumnNameToIndex(Map<String, Integer> colNameToIndex);

    public Map<String, Integer> getColumnToIndexCache();

    public void setColumnToIndexCache(Map<String, Integer> columnToIndexCache);

    void initializeFrom(ColumnDefinition columnDefinition);

    void exportTo(ColumnDefinition columnDefinition);

    int findColumn(String columnName, boolean useColumnNamesInFindColumn);
}

==> mysql-connector-java-6.0.6-sources.jar: com/mysql/cj/api/mysqla/result/ColumnDefinition.java <==
/*
  Copyright (c) 2016, Oracle and/or its affiliates. All rights reserved.

  The MySQL Connector/J is licensed under the terms of the GPLv2
  <http://www.gnu.org/licenses/old-licenses/gpl-2.0.html>, like most MySQL Connectors.
  There are special exceptions to the terms and conditions of the GPLv2 as it is applied to
  this software, see the FOSS License Exception
  <http://www.mysql.com/about/legal/licensing/foss-exception.html>.

  This program is free software; you can redistribute it and/or modify it under the terms
  of the GNU General Public License as published by the Free Software Foundation; version 2
  of the License.

  This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
  without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  See the GNU General Public License for more details.

  You should have received a copy of the GNU General Public License along with this
  program; if not, write to the Free Software Foundation, Inc., 51 Franklin St, Fifth
  Floor, Boston, MA 02110-1301  USA

 */

package com.mysql.cj.api.mysqla.result;

import java.util.Map;

import com.mysql.cj.core.result.Field;

/**
 * Represents Protocol::ColumnDefinition41 protocol entity.
 *
 */
public interface ColumnDefinition extends ProtocolEntity {

    Field[] getFields();

    void setFields(Field[] fields);

    /**
     * Builds a hash between column names and their indices for fast retrieval.
     * This is done lazily to support findColumn() and get*(String), as it
     * can be more expensive than just retrieving result set values by ordinal
     * index.
     */
    void buildIndexMapping();

    boolean hasBuiltIndexMapping();

    public Map<String, Integer> getColumnLabelToIndex();

    void setColumnLabelToIndex(Map<String, Integer> columnLabelToIndex);

    public Map<String, Integer> getFullColumnNameToIndex();

    void setFullColumnNameToIndex(Map<String, Integer> fullColNameToIndex);

    public Map<String, Integer> getColumnNameToIndex();

    void setColumnNameToIndex(Map<String, Integer> colNameToIndex);

    public Map<String, Integer> getColumnToIndexCache();

    public void setColumnToIndexCache(Map<String, Integer> columnToIndexCache);

    void initializeFrom(ColumnDefinition columnDefinition);

    void exportTo(ColumnDefinition columnDefinition);

    int findColumn(String columnName, boolean useColumnNamesInFindColumn);

    /**
     * Check if fields with type BLOB, MEDIUMBLOB, LONGBLOB, TEXT, MEDIUMTEXT or LONGTEXT exist in this ColumnDefinition.
     */
    boolean hasLargeFields();
}
